@@ -20,6 +20,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+#include <stdlib.h>
 #include <bonobo/bonobo-i18n.h>
 #include <libgda/gda-config.h>
 #include <gtk/gtklabel.h>
@@ -29,6 +31,7 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtktogglebutton.h>
+#include <libgnomedb/gnome-db-config.h>
 #include <libgnomedb/gnome-db-gray-bar.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <libgnomedb/gnome-db-window.h>
@@ -78,7 +81,7 @@ add_components_to_shortcut (GnomeDbShellSettings *settings)
 {
 	GList *components;
 	GList *node;
-	GdaComponentInfo *comp_info;
+	GnomeDbComponentInfo *comp_info;
 	gchar *str;
 
 	g_return_if_fail (GNOME_DB_IS_SHELL_SETTINGS (settings));
@@ -91,17 +94,17 @@ add_components_to_shortcut (GnomeDbShellSettings *settings)
 				  settings);
 
 	/* add the other available components */
-	components = gda_config_get_component_list (
+	components = gnome_db_config_get_component_list (
 		"repo_ids.has('IDL:GNOME/Database/UIShellComponent:1.0')");
 
 	for (node = g_list_first (components);
 	     node != NULL;
 	     node = g_list_next (node)) {
-		comp_info = (GdaComponentInfo *) node->data;
+		comp_info = (GnomeDbComponentInfo *) node->data;
 		str = g_strdup_printf ("%s/%s",
 				       GNOME_DB_SHELL_CONFIG_SECTION_LOAD,
 				       comp_info->id);
-		if (gda_config_has_key (str)) {
+		if (gnome_db_config_has_key (str)) {
 			GdaParameter *param;
 			gchar *shell_icon;
 			gchar *config_iid;
@@ -109,11 +112,11 @@ add_components_to_shortcut (GnomeDbShellSettings *settings)
 
 			/* get parameters */
 			param = gda_parameter_list_find (comp_info->properties,
-							 "shell-icon");
+							 "shell_icon");
 			shell_icon = gda_value_stringify (gda_parameter_get_value (param));
 
 			param = gda_parameter_list_find (comp_info->properties,
-							 "config-control");
+							 "config_control");
 			config_iid = gda_value_stringify (gda_parameter_get_value (param));
 
 			/* load the config control */
@@ -146,7 +149,7 @@ add_components_to_shortcut (GnomeDbShellSettings *settings)
 		g_free (str);
 	}
 
-	gda_config_free_component_list (components);
+	gnome_db_config_free_component_list (components);
 }
 
 static void
@@ -173,7 +176,7 @@ create_main_window_frame (GnomeDbShellSettings *settings, GtkTable *main_table)
 	button = gnome_db_new_check_button_widget (_("Show shortcut bar"));
 	gtk_toggle_button_set_active (
 		GTK_TOGGLE_BUTTON (button),
-		gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT));
+		gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT));
 	g_signal_connect (G_OBJECT (button), "toggled",
 			  G_CALLBACK (show_shortcut_bar_cb), settings);
 	gtk_table_attach (GTK_TABLE (table), button, 0, 5, 0, 1, GTK_FILL, GTK_FILL, 2, 2);
@@ -181,7 +184,7 @@ create_main_window_frame (GnomeDbShellSettings *settings, GtkTable *main_table)
 	button = gnome_db_new_check_button_widget (_("Show summary"));
 	gtk_toggle_button_set_active (
 		GTK_TOGGLE_BUTTON (button),
-		gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY));
+		gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY));
 	g_signal_connect (G_OBJECT (button), "toggled",
 			  G_CALLBACK (show_summary_cb), settings);
 	gtk_table_attach (GTK_TABLE (table), button, 0, 5, 1, 2, GTK_FILL, GTK_FILL, 2, 2);
@@ -193,7 +196,7 @@ create_main_window_frame (GnomeDbShellSettings *settings, GtkTable *main_table)
 	button = gnome_db_new_radio_button_widget (NULL, _("Save window position"));
 	gtk_toggle_button_set_active (
 		GTK_TOGGLE_BUTTON (button),
-		gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS));
+		gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS));
 	g_signal_connect (G_OBJECT (button), "toggled",
 			  G_CALLBACK (save_main_window_pos_cb), settings);
 	gtk_table_attach (GTK_TABLE (table), button, 0, 5, 3, 4,
@@ -205,7 +208,7 @@ create_main_window_frame (GnomeDbShellSettings *settings, GtkTable *main_table)
 		_("Use fixed position/size"));
 	gtk_toggle_button_set_active (
 		GTK_TOGGLE_BUTTON (button),
-		gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS));
+		gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS));
 	g_signal_connect (G_OBJECT (button), "toggled",
 			  G_CALLBACK (use_fixed_position_cb), settings);
 	gtk_table_attach (GTK_TABLE (table), button, 0, 5, 4, 5,
@@ -237,33 +240,33 @@ create_main_window_frame (GnomeDbShellSettings *settings, GtkTable *main_table)
 		_("Don't set size/position"));
 	gtk_toggle_button_set_active (
 		GTK_TOGGLE_BUTTON (button),
-		!gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS) &&
-		!gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS));
+		!gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS) &&
+		!gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS));
 	g_signal_connect (G_OBJECT (button), "toggled",
 			  G_CALLBACK (leave_main_window_pos_cb), settings);
 	gtk_table_attach (GTK_TABLE (table), button, 0, 5, 7, 8,
 			  GTK_FILL, GTK_FILL, 0, 0);
 
 	/* set initial values for position entries */
-	if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS)) {
+	if (gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS)) {
 		gchar bfr[32];
 
 		sprintf (bfr, "%d",
-			 gda_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X1));
+			 gnome_db_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X1));
 		gtk_entry_set_text (GTK_ENTRY (settings->priv->mw_left), bfr);
 
 		sprintf (bfr, "%d",
-			 gda_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y1));
+			 gnome_db_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y1));
 		gtk_entry_set_text (GTK_ENTRY (settings->priv->mw_top), bfr);
 
 		sprintf (bfr, "%d",
-			 gda_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X2) -
-			 gda_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X1));
+			 gnome_db_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X2) -
+			 gnome_db_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X1));
 		gtk_entry_set_text (GTK_ENTRY (settings->priv->mw_width), bfr);
 
 		sprintf (bfr, "%d",
-			 gda_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y2) -
-			 gda_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y1));
+			 gnome_db_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y2) -
+			 gnome_db_config_get_int (GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y1));
 		gtk_entry_set_text (GTK_ENTRY (settings->priv->mw_height), bfr);
 	}
 	else {
@@ -285,8 +288,8 @@ leave_main_window_pos_cb (GtkToggleButton *toggle, gpointer user_data)
 	g_return_if_fail (GNOME_DB_IS_SHELL_SETTINGS (settings));
 
 	if (gtk_toggle_button_get_active (toggle)) {
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS, FALSE);
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS, FALSE);
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS, FALSE);
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS, FALSE);
 
 		gtk_widget_set_sensitive (settings->priv->mw_left, FALSE);
 		gtk_widget_set_sensitive (settings->priv->mw_top, FALSE);
@@ -303,8 +306,8 @@ save_main_window_pos_cb (GtkToggleButton *toggle, gpointer user_data)
 	g_return_if_fail (GNOME_DB_IS_SHELL_SETTINGS (settings));
 
 	if (gtk_toggle_button_get_active (toggle)) {
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS, TRUE);
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS, FALSE);
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS, TRUE);
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS, FALSE);
 
 		gtk_widget_set_sensitive (settings->priv->mw_left, FALSE);
 		gtk_widget_set_sensitive (settings->priv->mw_top, FALSE);
@@ -343,9 +346,9 @@ show_shortcut_bar_cb (GtkToggleButton *toggle, gpointer user_data)
 	g_return_if_fail (GNOME_DB_IS_SHELL_SETTINGS (settings));
 
 	if (gtk_toggle_button_get_active (toggle))
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT, TRUE);
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT, TRUE);
 	else
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT, FALSE);
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT, FALSE);
 }
 
 static void
@@ -356,9 +359,9 @@ show_summary_cb (GtkToggleButton *toggle, gpointer user_data)
 	g_return_if_fail (GNOME_DB_IS_SHELL_SETTINGS (settings));
 
 	if (gtk_toggle_button_get_active (toggle))
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, TRUE);
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, TRUE);
 	else
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, FALSE);
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, FALSE);
 }
 
 static void
@@ -369,19 +372,19 @@ use_fixed_position_cb (GtkToggleButton *toggle, gpointer user_data)
 	g_return_if_fail (GNOME_DB_IS_SHELL_SETTINGS (settings));
 
 	if (gtk_toggle_button_get_active (toggle)) {
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS, FALSE);
-		gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS, TRUE);
-		gda_config_set_int (
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS, FALSE);
+		gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS, TRUE);
+		gnome_db_config_set_int (
 			GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X1,
 			atoi (gtk_entry_get_text (GTK_ENTRY (settings->priv->mw_left))));
-		gda_config_set_int (
+		gnome_db_config_set_int (
 			GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y1,
 			atoi (gtk_entry_get_text (GTK_ENTRY (settings->priv->mw_top))));
-		gda_config_set_int (
+		gnome_db_config_set_int (
 			GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X2,
 			atoi (gtk_entry_get_text (GTK_ENTRY (settings->priv->mw_left))) +
 			atoi (gtk_entry_get_text (GTK_ENTRY (settings->priv->mw_width))));
-		gda_config_set_int (
+		gnome_db_config_set_int (
 			GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y2,
 			atoi (gtk_entry_get_text (GTK_ENTRY (settings->priv->mw_top))) +
 			atoi (gtk_entry_get_text (GTK_ENTRY (settings->priv->mw_height))));
@@ -446,7 +449,7 @@ gnome_db_shell_settings_init (GnomeDbShellSettings *settings,
 	/* create the default configuration tab */
 	table = gnome_db_new_table_widget (3, 2, FALSE);
 
-	create_main_window_frame (settings, table);
+	create_main_window_frame (settings, GTK_TABLE (table));
 
 	gtk_notebook_append_page (GTK_NOTEBOOK (settings->priv->notebook),
 				  table, gtk_label_new (_("General")));
