@@ -121,9 +121,8 @@ add_components_to_shortcut (GnomeDbShell *shell)
 			gchar *shell_icon;
 
 			comp_info = (GnomeDbComponentInfo *) node->data;
-
 			param = gda_parameter_list_find (comp_info->properties,
-							 "shell-icon");
+							 "shell_icon");
 			shell_icon = gda_value_stringify (gda_parameter_get_value (param));
 			gnome_db_shortcut_append (
 				GNOME_DB_SHORTCUT (shell->priv->shortcut),
@@ -140,7 +139,7 @@ add_components_to_shortcut (GnomeDbShell *shell)
 	}
 
 	/* load the default component */
-	if (gda_config_has_key (GNOME_DB_SHELL_CONFIG_DEFAULT_COMPONENT)) {
+	if (gnome_db_config_has_key (GNOME_DB_SHELL_CONFIG_DEFAULT_COMPONENT)) {
 		/* FIXME */
 	}
 	else {
@@ -199,8 +198,8 @@ setup_window (GnomeDbShell *shell)
 	/* load state of window from configuration */
 	uic = gnome_db_window_get_ui_component (GNOME_DB_WINDOW (shell->priv->window));
 
-	if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT) ||
-	    !gda_config_has_key (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
+	if (gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT) ||
+	    !gnome_db_config_has_key (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
 		gtk_widget_show (shell->priv->shortcut);
 		shell->priv->show_shortcut = TRUE;
 		bonobo_ui_component_set_prop (uic, "/commands/ViewShortcutBar",
@@ -213,8 +212,8 @@ setup_window (GnomeDbShell *shell)
 					      "state", "0", NULL);
 	}
 
-	if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY) ||
-	    !gda_config_has_key (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
+	if (gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY) ||
+	    !gnome_db_config_has_key (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
 		gtk_widget_show (shell->priv->summary);
 		shell->priv->show_summary = TRUE;
 		bonobo_ui_component_set_prop (uic, "/commands/ViewSummary",
@@ -238,19 +237,26 @@ setup_window (GnomeDbShell *shell)
  */
 
 static void
-config_changed_cb (const gchar *path, gpointer user_data)
+config_changed_cb (GConfClient *client,
+		   guint cnxm_id,
+		   GConfEntry *entry,
+		   gpointer user_data)
+		   
 {
 	BonoboUIComponent *uic;
 	GnomeDbShell *shell = (GnomeDbShell *) user_data;
+	const gchar *path;
 
-	g_return_if_fail (path != NULL);
+	g_return_if_fail (entry != NULL);
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
+	path = entry->key;
+
 	uic = gnome_db_window_get_ui_component (GNOME_DB_WINDOW (shell->priv->window));
 
 	if (!strcmp (path, GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
 		/* hide/show shortcut bar */
-		if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
+		if (gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
 			gtk_widget_show (shell->priv->shortcut);
 			shell->priv->show_shortcut = TRUE;
 			bonobo_ui_component_set_prop (uic, "/commands/ViewShortcutBar",
@@ -265,7 +271,7 @@ config_changed_cb (const gchar *path, gpointer user_data)
 	}
 	else if (!strcmp (path, GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
 		/* hide/show summary */
-		if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
+		if (gnome_db_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
 			gtk_widget_show (shell->priv->summary);
 			shell->priv->show_summary = TRUE;
 			bonobo_ui_component_set_prop (uic, "/commands/ViewSummary",
@@ -530,9 +536,9 @@ gnome_db_shell_init (GnomeDbShell *shell, GnomeDbShellClass *klass)
 	shell->priv->activated_components = NULL;
 
 	/* add a listener for configuration changes */
-	shell->priv->config_listener_id = gda_config_add_listener (
+	shell->priv->config_listener_id = gnome_db_config_add_listener (
 		GNOME_DB_SHELL_CONFIG_SECTION_SHELL,
-		(GdaConfigListenerFunc) config_changed_cb,
+		config_changed_cb,
 		shell);
 }
 
@@ -550,7 +556,7 @@ gnome_db_shell_finalize (GObject *object)
 	g_list_free (shell->priv->activated_components);
 	shell->priv->activated_components = NULL;
 
-	gda_config_remove_listener (shell->priv->config_listener_id);
+	gnome_db_config_remove_listener (shell->priv->config_listener_id);
 
 	g_free (shell->priv);
 	shell->priv = NULL;
@@ -660,26 +666,26 @@ void
 gnome_db_shell_show_shortcut (GnomeDbShell *shell)
 {
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
-	gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT, TRUE);
+	gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT, TRUE);
 }
 
 void
 gnome_db_shell_hide_shortcut (GnomeDbShell *shell)
 {
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
-	gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT, FALSE);
+	gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT, FALSE);
 }
 
 void
 gnome_db_shell_show_summary (GnomeDbShell *shell)
 {
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
-	gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, TRUE);
+	gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, TRUE);
 }
 
 void
 gnome_db_shell_hide_summary (GnomeDbShell *shell)
 {
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
-	gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, FALSE);
+	gnome_db_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, FALSE);
 }
